@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2021 LG Electronics Inc.
 # SPDX-License-Identifier: Apache-2.0
+import os
 
 # System platform name
 WINDOWS = 'Windows'
@@ -19,10 +20,16 @@ ANDROID = 'android'
 SWIFT = 'swift'
 CARTHAGE = 'carthage'
 GO = 'go'
+NUGET = 'nuget'
+HELM = 'helm'
+UNITY = 'unity'
+CARGO = 'cargo'
+PNPM = 'pnpm'
 
 # Supported package name and manifest file
 SUPPORT_PACKAE = {
-    PYPI: ['requirements.txt', 'setup.py'],
+    PYPI: ['requirements.txt', 'setup.py', 'pyproject.toml'],
+    PNPM: 'pnpm-lock.yaml',
     NPM: 'package.json',
     MAVEN: 'pom.xml',
     GRADLE: 'build.gradle',
@@ -31,7 +38,17 @@ SUPPORT_PACKAE = {
     ANDROID: 'build.gradle',
     SWIFT: 'Package.resolved',
     CARTHAGE: 'Cartfile.resolved',
-    GO: 'go.mod'
+    GO: 'go.mod',
+    NUGET: ['packages.config', os.path.join('obj', 'project.assets.json')],
+    HELM: 'Chart.yaml',
+    UNITY: os.path.join('Library', 'PackageManager', 'ProjectCache'),
+    CARGO: 'Cargo.toml'
+}
+
+SUGGESTED_PACKAGE = {
+    'Podfile': COCOAPODS,
+    'Package.swift': SWIFT,
+    'Cartfile': CARTHAGE
 }
 
 # default android app name
